%% TransmonABCD.m     SJW 08/06/2009
%
% This calculates the ABCD matrix for the Transmon table laid out in
% the  D0900446-v7 zemax file.  Obviously,  I have necessarily simplified
% the schematic with the intent to check limiting apertures,  etc. layout
% is:
%
%  ETM -> Tel1 -> Tel2 -> Lens1 -> Lens2 -> QPD1 -> QPD2
%
% We calculate the limiting apertures at each place,  and the largest beam
% displacements and angles everywhere.  We eventually calculate the
% sensitivities to displacement for gouy phase readout.
%
%  ITM ROC = 1970 m
%  ETM ROC = 2190 m
%  ETM thickness = 20.4 cm
%  t1->t2 = 1936.1 mm
%  t2->l1 = 937.0 mm 
%  l1back ->l2front = 220.0 mm
%  l2back->Q1 = 315 mm
%  Q2->Q2 = 740 mm

%% Starting beam
[z0,z1,z2] = cavHG(3995, 1970, 2190);                 % The waist is defined by the arm cavity
q_input = waist2q(sqrt(z0*1.064e-6/pi), 0);    
 
%% Matrix definitions
dist = @(x) [1 x(1); 0 1];                           % distance
mirror = @(R) [1 0; -2/R(1) 1];                      % radius
dielectric = @(n1,n2,R) [1 0; (n1-n2)/(R*n2) n1/n2]; % n1, n2, R for an interface
lens = @(r1, r2, th) dielectric(1.45, 1, r2)*dist(th)*dielectric(1, 1.45, r1);
       % r1, r2, thickness.  R1 > 0 for convex,  R1 < 0 for concave.  
       % R2 vice versa.  Assumed fused silica, hence n = 1.45

       
% Matrix transformation
qNew = @(q,ABCD) (q*ABCD(1,1)+ABCD(1,2)) / (q*ABCD(2,1)+ABCD(2,2));

%% Model parameters
zt1_t2 = 1.9362;
zt2_l1 = 1;
zl1_l2 = 0.235;
zl2_q1 = 0.26;
zq1_q2 = 0.5;

lens1 =  lens(0.1545, inf, 4e-3);   % CVI xxx
lens2 =  lens(inf, 0.0644, 2e-3);   % CVI yyy
lens1 = mirror(2*0.344);
lens2 = mirror(2*-0.143);

%% %%%%%%%%  ABCD matrices as a function of the telescope length
% afact is cos(AOI) or 1/cos(AOI) depending on the DOF explored
AOI = 4.2/180*pi;
toTelescope = lens(-2070, inf, 0.204) * dist(2115);

telescope = @(L,afact) mirror(-0.133*afact) * dist(L) * mirror(4.000)*toTelescope;
firstlens = @(L,afact) lens1 * dist(zt2_l1) * telescope(L,afact);
secondlens = @(L,afact) lens(inf, 0.0644,2e-3) * dist(zl1_l2) * firstlens(L,afact);
q1  = @(L,afact) dist(zl2_q1)*secondlens(L,afact);
q2 = @(L,afact) dist(zq1_q2)*q1(L,afact);

gouyDiff = @(L, afact, q_in, M_q1, M_q2) ...
    q2gouy(qNew(q_in, M_q1(L,afact)))- q2gouy(qNew(q_in, M_q2(L,afact)));

zz = [-5e-4:1e-5:5e-4] + zt1_t2; 

figure(1)
for ii = 1:length(zz)
    gD_h(ii) = gouyDiff(zz(ii), cos(AOI), q_input, q1, q2);
    gD_v(ii) = gouyDiff(zz(ii), 1/cos(AOI), q_input, q1, q2);
end
plot((zz-zt1_t2)*1e3, gD_h, (zz-zt1_t2)*1e3, gD_v);
legend('Horizontal DOF', 'Vertical DOF');
ylabel('Gouy angle [deg]');

axis([-.5 .5 60 120]);
grid
%% Find the tuning range:

[m] = max(find(gD_h < 72));
min_length = zz(m)

[m] = min(find(gD_v < 72));
max_length = zz(m)


%% Gouy phases and waist sizes
if 0
    disp('            QPD1 waist     QPD2 waist    phi_1-phi_2')
    fprintf(1, 'Vertical:   %.0f\t %.0f\t %.0f\n', ...
        q2waist(qNew(q_input, q1_v))*1e6, q2waist(qNew(q_input,q2_v))*1e6, ...
        q2gouy(qNew(q_input, q1_v))- q2gouy(qNew(q_input,q2_v)));
    fprintf(1, 'Horizontal:   %.0f\t %.0f\t %.0f\n', ...
        q2waist(qNew(q_input, q1_h))*1e6, q2waist(qNew(q_input,q2_h))*1e6, ...
        q2gouy(qNew(q_input, q1_h))- q2gouy(qNew(q_input,q2_h)));
figure(1);

zz = 0:0.01:500;
plot(zz,q2waist(qofzed(qNew(q_input, telescope_h), zz)), ...
    zz,q2waist(qofzed(qNew(q_input, telescope_v), zz)), ...
    zz,q2waist(qofzed(qNew(q_input, telescope_v), zz))./q2waist(qofzed(qNew(q_input, telescope_h), zz))    )
title('Telescope')

end



 